@@ -4,4 +4,7 @@
 # file 'LICENSE', which is part of this source code package.
 #       Copyright (c) 2011 R Pratap Chakravarthy
 
+"""Package directory contain plugins implementing 
+:class:`tayra.interfaces.ITayraFilterBlock` interface specification."""
+
 import tayra.filterblocks.pycode
