@@ -170,7 +170,7 @@ def hd_styles() :
   _m.extend( ['-webkit-text-shadow : 0px 1px 1px #FFF, 0px 1px 1px black;', '\n    '] )
   # lineno:65
   _m.extend( ['}', '\n\n'] )
-  _m.handletag( _m.popbuftext(), _m.popbuftext(), indent=False, nl='')
+  _m.handletag( _m.popbuftext(), _m.popbuftext(), **{'nl': '', 'oprune': False, 'indent': False, 'iprune': False} )
   return _m.popbuftext()
 
 
@@ -230,7 +230,7 @@ def hd_script() :
   _m.extend( ['});', '\n    '] )
   # lineno:91
   _m.extend( ['});', '\n\n'] )
-  _m.handletag( _m.popbuftext(), _m.popbuftext(), indent=False, nl='')
+  _m.handletag( _m.popbuftext(), _m.popbuftext(), **{'nl': '', 'oprune': False, 'indent': False, 'iprune': False} )
   return _m.popbuftext()
 
 
@@ -254,7 +254,7 @@ def body_centerpane() :
   _m.extend( [' Pluggdapps in a nutshell, that it is today and that it will be', '\n      '] )
   # lineno:97
   _m.extend( ['tomorrow.', '\n    '] )
-  _m.handletag( _m.popbuftext(), _m.popbuftext(), indent=False, nl='')
+  _m.handletag( _m.popbuftext(), _m.popbuftext(), **{'nl': '', 'oprune': False, 'indent': False, 'iprune': False} )
   # lineno:98
   _m.pushbuf()
   _m.extend( ['<div .search>'] )
@@ -265,14 +265,14 @@ def body_centerpane() :
   _m.extend( ['<inptext .search placeholder="Search features ...">'] )
   _m.pushbuf()
   _m.extend( ['\n      '] )
-  _m.handletag( _m.popbuftext(), _m.popbuftext(), indent=False, nl='')
+  _m.handletag( _m.popbuftext(), _m.popbuftext(), **{'nl': '', 'oprune': False, 'indent': False, 'iprune': False} )
   # lineno:100
   _m.pushbuf()
   _m.extend( ['<a .showall.fntxsmall.pointer>'] )
   _m.pushbuf()
   # lineno:100
   _m.extend( [' show-all', '\n      '] )
-  _m.handletag( _m.popbuftext(), _m.popbuftext(), indent=False, nl='')
+  _m.handletag( _m.popbuftext(), _m.popbuftext(), **{'nl': '', 'oprune': False, 'indent': False, 'iprune': False} )
   # lineno:101
   _m.pushbuf()
   _m.extend( ['<fieldset .floatr>'] )
@@ -284,7 +284,7 @@ def body_centerpane() :
   _m.pushbuf()
   # lineno:102
   _m.extend( [' Common search terms', '\n        '] )
-  _m.handletag( _m.popbuftext(), _m.popbuftext(), indent=False, nl='')
+  _m.handletag( _m.popbuftext(), _m.popbuftext(), **{'nl': '', 'oprune': False, 'indent': False, 'iprune': False} )
   # lineno:103
   _m.pushbuf()
   _m.extend( ['<div .keywords>'] )
@@ -296,45 +296,45 @@ def body_centerpane() :
   _m.pushbuf()
   # lineno:104
   _m.extend( ['plugin', '\n          '] )
-  _m.handletag( _m.popbuftext(), _m.popbuftext(), indent=False, nl='')
+  _m.handletag( _m.popbuftext(), _m.popbuftext(), **{'nl': '', 'oprune': False, 'indent': False, 'iprune': False} )
   # lineno:105
   _m.pushbuf()
   _m.extend( ['<span .dsrch.pointer.ralign>'] )
   _m.pushbuf()
   # lineno:105
   _m.extend( ['template', '\n          '] )
-  _m.handletag( _m.popbuftext(), _m.popbuftext(), indent=False, nl='')
+  _m.handletag( _m.popbuftext(), _m.popbuftext(), **{'nl': '', 'oprune': False, 'indent': False, 'iprune': False} )
   # lineno:106
   _m.pushbuf()
   _m.extend( ['<span .dsrch.pointer.ralign>'] )
   _m.pushbuf()
   # lineno:106
   _m.extend( ['web|html', '\n          '] )
-  _m.handletag( _m.popbuftext(), _m.popbuftext(), indent=False, nl='')
+  _m.handletag( _m.popbuftext(), _m.popbuftext(), **{'nl': '', 'oprune': False, 'indent': False, 'iprune': False} )
   # lineno:107
   _m.pushbuf()
   _m.extend( ['<span .dsrch.pointer.ralign>'] )
   _m.pushbuf()
   # lineno:107
   _m.extend( ['couch', '\n          '] )
-  _m.handletag( _m.popbuftext(), _m.popbuftext(), indent=False, nl='')
+  _m.handletag( _m.popbuftext(), _m.popbuftext(), **{'nl': '', 'oprune': False, 'indent': False, 'iprune': False} )
   # lineno:108
   _m.pushbuf()
   _m.extend( ['<span .dsrch.pointer.ralign>'] )
   _m.pushbuf()
   # lineno:108
   _m.extend( ['tayra', '\n          '] )
-  _m.handletag( _m.popbuftext(), _m.popbuftext(), indent=False, nl='')
+  _m.handletag( _m.popbuftext(), _m.popbuftext(), **{'nl': '', 'oprune': False, 'indent': False, 'iprune': False} )
   # lineno:109
   _m.pushbuf()
   _m.extend( ['<span .dsrch.pointer.ralign>'] )
   _m.pushbuf()
   # lineno:109
   _m.extend( ['program', '\n    '] )
-  _m.handletag( _m.popbuftext(), _m.popbuftext(), indent=False, nl='')
-  _m.handletag( _m.popbuftext(), _m.popbuftext(), indent=False, nl='')
-  _m.handletag( _m.popbuftext(), _m.popbuftext(), indent=False, nl='')
-  _m.handletag( _m.popbuftext(), _m.popbuftext(), indent=False, nl='')
+  _m.handletag( _m.popbuftext(), _m.popbuftext(), **{'nl': '', 'oprune': False, 'indent': False, 'iprune': False} )
+  _m.handletag( _m.popbuftext(), _m.popbuftext(), **{'nl': '', 'oprune': False, 'indent': False, 'iprune': False} )
+  _m.handletag( _m.popbuftext(), _m.popbuftext(), **{'nl': '', 'oprune': False, 'indent': False, 'iprune': False} )
+  _m.handletag( _m.popbuftext(), _m.popbuftext(), **{'nl': '', 'oprune': False, 'indent': False, 'iprune': False} )
   # lineno:110
   _m.pushbuf()
   _m.extend( ['<ul>'] )
@@ -346,7 +346,7 @@ def body_centerpane() :
   _m.pushbuf()
   # lineno:111
   _m.extend( ['Build applications on web-technologies. Build it on pluggdapps.', '\n      '] )
-  _m.handletag( _m.popbuftext(), _m.popbuftext(), indent=False, nl='')
+  _m.handletag( _m.popbuftext(), _m.popbuftext(), **{'nl': '', 'oprune': False, 'indent': False, 'iprune': False} )
   # lineno:112
   _m.pushbuf()
   _m.extend( ['<li>'] )
@@ -355,7 +355,7 @@ def body_centerpane() :
   _m.extend( ['Linus took unix to all programmers, and apt-get took Linux to all people.', '\n        '] )
   # lineno:113
   _m.extend( ['In pluggdapps, deploy a website by installing a package.', '\n      '] )
-  _m.handletag( _m.popbuftext(), _m.popbuftext(), indent=False, nl='')
+  _m.handletag( _m.popbuftext(), _m.popbuftext(), **{'nl': '', 'oprune': False, 'indent': False, 'iprune': False} )
   # lineno:114
   _m.pushbuf()
   _m.extend( ['<li>'] )
@@ -366,7 +366,7 @@ def body_centerpane() :
   _m.extend( ['or plugins or just couple of template files, deploy them by installing an egg', '\n        '] )
   # lineno:116
   _m.extend( ['package.', '\n      '] )
-  _m.handletag( _m.popbuftext(), _m.popbuftext(), indent=False, nl='')
+  _m.handletag( _m.popbuftext(), _m.popbuftext(), **{'nl': '', 'oprune': False, 'indent': False, 'iprune': False} )
   # lineno:117
   _m.pushbuf()
   _m.extend( ['<li>'] )
@@ -375,14 +375,14 @@ def body_centerpane() :
   _m.extend( ['MVC (Model-View-Controller) is great. Plugin architecture is great. Do them', '\n        '] )
   # lineno:118
   _m.extend( ['both in pluggdapps and get the best of both worlds.', '\n      '] )
-  _m.handletag( _m.popbuftext(), _m.popbuftext(), indent=False, nl='')
+  _m.handletag( _m.popbuftext(), _m.popbuftext(), **{'nl': '', 'oprune': False, 'indent': False, 'iprune': False} )
   # lineno:119
   _m.pushbuf()
   _m.extend( ['<li>'] )
   _m.pushbuf()
   # lineno:119
   _m.extend( ['Should client and server run on different machines ? Not with pluggdapps.', '\n      '] )
-  _m.handletag( _m.popbuftext(), _m.popbuftext(), indent=False, nl='')
+  _m.handletag( _m.popbuftext(), _m.popbuftext(), **{'nl': '', 'oprune': False, 'indent': False, 'iprune': False} )
   # lineno:120
   _m.pushbuf()
   _m.extend( ['<li>'] )
@@ -391,7 +391,7 @@ def body_centerpane() :
   _m.extend( ['Pluggdapps run on python and javascript and web-browser and uses erlang for', '\n        '] )
   # lineno:121
   _m.extend( ['database, hence, it can run on any device supporting them. Why not ?', '\n      '] )
-  _m.handletag( _m.popbuftext(), _m.popbuftext(), indent=False, nl='')
+  _m.handletag( _m.popbuftext(), _m.popbuftext(), **{'nl': '', 'oprune': False, 'indent': False, 'iprune': False} )
   # lineno:122
   _m.pushbuf()
   _m.extend( ['<li>'] )
@@ -400,7 +400,7 @@ def body_centerpane() :
   _m.extend( ['Library is a tool. Great libraries are stateless and re-entrant. For', '\n        '] )
   # lineno:123
   _m.extend( ['pluggdapps, even applications are stateless and re-entrant.', '\n      '] )
-  _m.handletag( _m.popbuftext(), _m.popbuftext(), indent=False, nl='')
+  _m.handletag( _m.popbuftext(), _m.popbuftext(), **{'nl': '', 'oprune': False, 'indent': False, 'iprune': False} )
   # lineno:124
   _m.pushbuf()
   _m.extend( ['<li>'] )
@@ -409,14 +409,14 @@ def body_centerpane() :
   _m.extend( ['A framework is just a library, with callback APIs. A plugin is just a library,', '\n        '] )
   # lineno:125
   _m.extend( ['with callback APIs. Hence, plugins are great way to design frameworks.', '\n      '] )
-  _m.handletag( _m.popbuftext(), _m.popbuftext(), indent=False, nl='')
+  _m.handletag( _m.popbuftext(), _m.popbuftext(), **{'nl': '', 'oprune': False, 'indent': False, 'iprune': False} )
   # lineno:126
   _m.pushbuf()
   _m.extend( ['<li>'] )
   _m.pushbuf()
   # lineno:126
   _m.extend( ['To access a library, import them. To access plugins, query for them.', '\n      '] )
-  _m.handletag( _m.popbuftext(), _m.popbuftext(), indent=False, nl='')
+  _m.handletag( _m.popbuftext(), _m.popbuftext(), **{'nl': '', 'oprune': False, 'indent': False, 'iprune': False} )
   # lineno:127
   _m.pushbuf()
   _m.extend( ['<li>'] )
@@ -425,7 +425,7 @@ def body_centerpane() :
   _m.extend( ['Pluggdapps is not first to do it right, it merely tracks the footsteps of', '\n        '] )
   # lineno:128
   _m.extend( ['its masters - Python, Zope, Pyramid, ...', '\n      '] )
-  _m.handletag( _m.popbuftext(), _m.popbuftext(), indent=False, nl='')
+  _m.handletag( _m.popbuftext(), _m.popbuftext(), **{'nl': '', 'oprune': False, 'indent': False, 'iprune': False} )
   # lineno:129
   _m.pushbuf()
   _m.extend( ['<li>'] )
@@ -438,14 +438,14 @@ def body_centerpane() :
   _m.extend( ['a bunch of code implementing an interface. That pretty much sums up the', '\n        '] )
   # lineno:132
   _m.extend( ['plugin architecture.', '\n      '] )
-  _m.handletag( _m.popbuftext(), _m.popbuftext(), indent=False, nl='')
+  _m.handletag( _m.popbuftext(), _m.popbuftext(), **{'nl': '', 'oprune': False, 'indent': False, 'iprune': False} )
   # lineno:133
   _m.pushbuf()
   _m.extend( ['<li>'] )
   _m.pushbuf()
   # lineno:133
   _m.extend( ['Install applications and access them on the url.', '\n      '] )
-  _m.handletag( _m.popbuftext(), _m.popbuftext(), indent=False, nl='')
+  _m.handletag( _m.popbuftext(), _m.popbuftext(), **{'nl': '', 'oprune': False, 'indent': False, 'iprune': False} )
   # lineno:134
   _m.pushbuf()
   _m.extend( ['<li>'] )
@@ -454,7 +454,7 @@ def body_centerpane() :
   _m.extend( ['Configure and customize application along with modules, interfaces and plugins', '\n        '] )
   # lineno:135
   _m.extend( ['used by the application. Configure them in .ini file, configure them via web.', '\n      '] )
-  _m.handletag( _m.popbuftext(), _m.popbuftext(), indent=False, nl='')
+  _m.handletag( _m.popbuftext(), _m.popbuftext(), **{'nl': '', 'oprune': False, 'indent': False, 'iprune': False} )
   # lineno:136
   _m.pushbuf()
   _m.extend( ['<li>'] )
@@ -465,7 +465,7 @@ def body_centerpane() :
   _m.extend( ['script. While the default is script, choose the one that fits, and', '\n        '] )
   # lineno:138
   _m.extend( ['applications can be agnostic to how they are mounted.', '\n      '] )
-  _m.handletag( _m.popbuftext(), _m.popbuftext(), indent=False, nl='')
+  _m.handletag( _m.popbuftext(), _m.popbuftext(), **{'nl': '', 'oprune': False, 'indent': False, 'iprune': False} )
   # lineno:139
   _m.pushbuf()
   _m.extend( ['<li>'] )
@@ -474,14 +474,14 @@ def body_centerpane() :
   _m.extend( ['Url-rewriting. Requests are automatically routed to the mounted', '\n        '] )
   # lineno:140
   _m.extend( ['application.', '\n      '] )
-  _m.handletag( _m.popbuftext(), _m.popbuftext(), indent=False, nl='')
+  _m.handletag( _m.popbuftext(), _m.popbuftext(), **{'nl': '', 'oprune': False, 'indent': False, 'iprune': False} )
   # lineno:141
   _m.pushbuf()
   _m.extend( ['<li>'] )
   _m.pushbuf()
   # lineno:141
   _m.extend( ['Cross application access. For apps to access each other in the same run-time.', '\n      '] )
-  _m.handletag( _m.popbuftext(), _m.popbuftext(), indent=False, nl='')
+  _m.handletag( _m.popbuftext(), _m.popbuftext(), **{'nl': '', 'oprune': False, 'indent': False, 'iprune': False} )
   # lineno:142
   _m.pushbuf()
   _m.extend( ['<li>'] )
@@ -490,7 +490,7 @@ def body_centerpane() :
   _m.extend( ['Scaffolding. From first key-stroke to first application page in less than', '\n        '] )
   # lineno:143
   _m.extend( ['30 seconds.', '\n      '] )
-  _m.handletag( _m.popbuftext(), _m.popbuftext(), indent=False, nl='')
+  _m.handletag( _m.popbuftext(), _m.popbuftext(), **{'nl': '', 'oprune': False, 'indent': False, 'iprune': False} )
   # lineno:144
   _m.pushbuf()
   _m.extend( ['<li>'] )
@@ -499,7 +499,7 @@ def body_centerpane() :
   _m.extend( ['Authenticate users and authorize them with permissions. Off-the-shelf plugins', '\n        '] )
   # lineno:145
   _m.extend( ['available for challenging credentials and interfacing with backend store.', '\n      '] )
-  _m.handletag( _m.popbuftext(), _m.popbuftext(), indent=False, nl='')
+  _m.handletag( _m.popbuftext(), _m.popbuftext(), **{'nl': '', 'oprune': False, 'indent': False, 'iprune': False} )
   # lineno:146
   _m.pushbuf()
   _m.extend( ['<li>'] )
@@ -508,7 +508,7 @@ def body_centerpane() :
   _m.extend( ['Your browser has got the best documentation engine ever and wiki makes it', '\n        '] )
   # lineno:147
   _m.extend( ['accessible. Use EazyText to create content for your apps.', '\n      '] )
-  _m.handletag( _m.popbuftext(), _m.popbuftext(), indent=False, nl='')
+  _m.handletag( _m.popbuftext(), _m.popbuftext(), **{'nl': '', 'oprune': False, 'indent': False, 'iprune': False} )
   # lineno:148
   _m.pushbuf()
   _m.extend( ['<li>'] )
@@ -517,7 +517,7 @@ def body_centerpane() :
   _m.extend( ['EazyText wiki markup. Generate HTML documents with out compromising on its', '\n        '] )
   # lineno:149
   _m.extend( ['readability.', '\n      '] )
-  _m.handletag( _m.popbuftext(), _m.popbuftext(), indent=False, nl='')
+  _m.handletag( _m.popbuftext(), _m.popbuftext(), **{'nl': '', 'oprune': False, 'indent': False, 'iprune': False} )
   # lineno:150
   _m.pushbuf()
   _m.extend( ['<li>'] )
@@ -526,14 +526,14 @@ def body_centerpane() :
   _m.extend( ['With EazyText highlight your text as bold, italic, underline, subscript,', '\n        '] )
   # lineno:151
   _m.extend( ['superscript and more.', '\n      '] )
-  _m.handletag( _m.popbuftext(), _m.popbuftext(), indent=False, nl='')
+  _m.handletag( _m.popbuftext(), _m.popbuftext(), **{'nl': '', 'oprune': False, 'indent': False, 'iprune': False} )
   # lineno:152
   _m.pushbuf()
   _m.extend( ['<li>'] )
   _m.pushbuf()
   # lineno:152
   _m.extend( ['EazyText can hyperlink documents and images.', '\n      '] )
-  _m.handletag( _m.popbuftext(), _m.popbuftext(), indent=False, nl='')
+  _m.handletag( _m.popbuftext(), _m.popbuftext(), **{'nl': '', 'oprune': False, 'indent': False, 'iprune': False} )
   # lineno:153
   _m.pushbuf()
   _m.extend( ['<li>'] )
@@ -542,35 +542,35 @@ def body_centerpane() :
   _m.extend( ['Text in EazyText looks natural for reading. All the same it can generate', '\n        '] )
   # lineno:154
   _m.extend( ['lists, tables, definitions, blockquotes and paragraphs.', '\n      '] )
-  _m.handletag( _m.popbuftext(), _m.popbuftext(), indent=False, nl='')
+  _m.handletag( _m.popbuftext(), _m.popbuftext(), **{'nl': '', 'oprune': False, 'indent': False, 'iprune': False} )
   # lineno:155
   _m.pushbuf()
   _m.extend( ['<li>'] )
   _m.pushbuf()
   # lineno:155
   _m.extend( ['EazyText macros, create new functions and use them in your documents.', '\n      '] )
-  _m.handletag( _m.popbuftext(), _m.popbuftext(), indent=False, nl='')
+  _m.handletag( _m.popbuftext(), _m.popbuftext(), **{'nl': '', 'oprune': False, 'indent': False, 'iprune': False} )
   # lineno:156
   _m.pushbuf()
   _m.extend( ['<li>'] )
   _m.pushbuf()
   # lineno:156
   _m.extend( ['EazyText extensions, extend the wiki engine.', '\n      '] )
-  _m.handletag( _m.popbuftext(), _m.popbuftext(), indent=False, nl='')
+  _m.handletag( _m.popbuftext(), _m.popbuftext(), **{'nl': '', 'oprune': False, 'indent': False, 'iprune': False} )
   # lineno:157
   _m.pushbuf()
   _m.extend( ['<li>'] )
   _m.pushbuf()
   # lineno:157
   _m.extend( ['Become an expert in EazyText and create interactive documents.', '\n      '] )
-  _m.handletag( _m.popbuftext(), _m.popbuftext(), indent=False, nl='')
+  _m.handletag( _m.popbuftext(), _m.popbuftext(), **{'nl': '', 'oprune': False, 'indent': False, 'iprune': False} )
   # lineno:158
   _m.pushbuf()
   _m.extend( ['<li>'] )
   _m.pushbuf()
   # lineno:158
   _m.extend( ['And EazyText is moving towards HTML5.', '\n      '] )
-  _m.handletag( _m.popbuftext(), _m.popbuftext(), indent=False, nl='')
+  _m.handletag( _m.popbuftext(), _m.popbuftext(), **{'nl': '', 'oprune': False, 'indent': False, 'iprune': False} )
   # lineno:159
   _m.pushbuf()
   _m.extend( ['<li>'] )
@@ -579,21 +579,21 @@ def body_centerpane() :
   _m.extend( ['With CSS and javascript, your browser can be way more than just a document', '\n        '] )
   # lineno:160
   _m.extend( ['renderer. Use tayra templates to design your front end.', '\n      '] )
-  _m.handletag( _m.popbuftext(), _m.popbuftext(), indent=False, nl='')
+  _m.handletag( _m.popbuftext(), _m.popbuftext(), **{'nl': '', 'oprune': False, 'indent': False, 'iprune': False} )
   # lineno:161
   _m.pushbuf()
   _m.extend( ['<li>'] )
   _m.pushbuf()
   # lineno:161
   _m.extend( ['HTML is verbose. Make it consise with Tayra.', '\n      '] )
-  _m.handletag( _m.popbuftext(), _m.popbuftext(), indent=False, nl='')
+  _m.handletag( _m.popbuftext(), _m.popbuftext(), **{'nl': '', 'oprune': False, 'indent': False, 'iprune': False} )
   # lineno:162
   _m.pushbuf()
   _m.extend( ['<li>'] )
   _m.pushbuf()
   # lineno:162
   _m.extend( ['CSS Selector. That which pulls HTML, Javascript and CSS together.', '\n      '] )
-  _m.handletag( _m.popbuftext(), _m.popbuftext(), indent=False, nl='')
+  _m.handletag( _m.popbuftext(), _m.popbuftext(), **{'nl': '', 'oprune': False, 'indent': False, 'iprune': False} )
   # lineno:163
   _m.pushbuf()
   _m.extend( ['<li>'] )
@@ -602,21 +602,21 @@ def body_centerpane() :
   _m.extend( ['Tayra templating language. Bunch of syntax wrapped around a bunch of', '\n        '] )
   # lineno:164
   _m.extend( ['specification. Adapt the language to your needs.', '\n      '] )
-  _m.handletag( _m.popbuftext(), _m.popbuftext(), indent=False, nl='')
+  _m.handletag( _m.popbuftext(), _m.popbuftext(), **{'nl': '', 'oprune': False, 'indent': False, 'iprune': False} )
   # lineno:165
   _m.pushbuf()
   _m.extend( ['<li>'] )
   _m.pushbuf()
   # lineno:165
   _m.extend( ['Intendations are only natural to html. Why not enforce them ?', '\n      '] )
-  _m.handletag( _m.popbuftext(), _m.popbuftext(), indent=False, nl='')
+  _m.handletag( _m.popbuftext(), _m.popbuftext(), **{'nl': '', 'oprune': False, 'indent': False, 'iprune': False} )
   # lineno:166
   _m.pushbuf()
   _m.extend( ['<li>'] )
   _m.pushbuf()
   # lineno:166
   _m.extend( ['Tayra templates. Define templates as function.', '\n      '] )
-  _m.handletag( _m.popbuftext(), _m.popbuftext(), indent=False, nl='')
+  _m.handletag( _m.popbuftext(), _m.popbuftext(), **{'nl': '', 'oprune': False, 'indent': False, 'iprune': False} )
   # lineno:167
   _m.pushbuf()
   _m.extend( ['<li>'] )
@@ -625,7 +625,7 @@ def body_centerpane() :
   _m.extend( ['Tayra templates. Organise template functions as modules. Import them in other', '\n        '] )
   # lineno:168
   _m.extend( ['templates.', '\n      '] )
-  _m.handletag( _m.popbuftext(), _m.popbuftext(), indent=False, nl='')
+  _m.handletag( _m.popbuftext(), _m.popbuftext(), **{'nl': '', 'oprune': False, 'indent': False, 'iprune': False} )
   # lineno:169
   _m.pushbuf()
   _m.extend( ['<li>'] )
@@ -634,7 +634,7 @@ def body_centerpane() :
   _m.extend( ['Tayra templates. Templates are modules. Templates are objects. Use template', '\n        '] )
   # lineno:170
   _m.extend( ['inheritance to design layouts.', '\n      '] )
-  _m.handletag( _m.popbuftext(), _m.popbuftext(), indent=False, nl='')
+  _m.handletag( _m.popbuftext(), _m.popbuftext(), **{'nl': '', 'oprune': False, 'indent': False, 'iprune': False} )
   # lineno:171
   _m.pushbuf()
   _m.extend( ['<li>'] )
@@ -643,21 +643,21 @@ def body_centerpane() :
   _m.extend( ['Tayra templates. Specify template interface. Implement template plugins. Use', '\n        '] )
   # lineno:172
   _m.extend( ['them else-where.', '\n      '] )
-  _m.handletag( _m.popbuftext(), _m.popbuftext(), indent=False, nl='')
+  _m.handletag( _m.popbuftext(), _m.popbuftext(), **{'nl': '', 'oprune': False, 'indent': False, 'iprune': False} )
   # lineno:173
   _m.pushbuf()
   _m.extend( ['<li>'] )
   _m.pushbuf()
   # lineno:173
   _m.extend( ['If you like decorators in python, you will like it in Tayra templates.', '\n      '] )
-  _m.handletag( _m.popbuftext(), _m.popbuftext(), indent=False, nl='')
+  _m.handletag( _m.popbuftext(), _m.popbuftext(), **{'nl': '', 'oprune': False, 'indent': False, 'iprune': False} )
   # lineno:174
   _m.pushbuf()
   _m.extend( ['<li>'] )
   _m.pushbuf()
   # lineno:174
   _m.extend( ['NoSQL is cool. CouchDB is radical. Program your database with CouchPy.', '\n      '] )
-  _m.handletag( _m.popbuftext(), _m.popbuftext(), indent=False, nl='')
+  _m.handletag( _m.popbuftext(), _m.popbuftext(), **{'nl': '', 'oprune': False, 'indent': False, 'iprune': False} )
   # lineno:175
   _m.pushbuf()
   _m.extend( ['<li>'] )
@@ -666,14 +666,14 @@ def body_centerpane() :
   _m.extend( ["Don't you feel stored procedure in SQL as an after-thought ? After programming", '\n        '] )
   # lineno:176
   _m.extend( ['(views,...) in CouchDB, there is a high chance you might.', '\n      '] )
-  _m.handletag( _m.popbuftext(), _m.popbuftext(), indent=False, nl='')
+  _m.handletag( _m.popbuftext(), _m.popbuftext(), **{'nl': '', 'oprune': False, 'indent': False, 'iprune': False} )
   # lineno:177
   _m.pushbuf()
   _m.extend( ['<li>'] )
   _m.pushbuf()
   # lineno:177
   _m.extend( ['CouchDB on HTTP is nothing but CRUD on ReST.', '\n      '] )
-  _m.handletag( _m.popbuftext(), _m.popbuftext(), indent=False, nl='')
+  _m.handletag( _m.popbuftext(), _m.popbuftext(), **{'nl': '', 'oprune': False, 'indent': False, 'iprune': False} )
   # lineno:178
   _m.pushbuf()
   _m.extend( ['<li>'] )
@@ -682,7 +682,7 @@ def body_centerpane() :
   _m.extend( ['CouchPy for CouchDB. Model. Transact. Replicate. Program. Query. Eventually', '\n        '] )
   # lineno:179
   _m.extend( ['consistent with MVCC.', '\n      '] )
-  _m.handletag( _m.popbuftext(), _m.popbuftext(), indent=False, nl='')
+  _m.handletag( _m.popbuftext(), _m.popbuftext(), **{'nl': '', 'oprune': False, 'indent': False, 'iprune': False} )
   # lineno:180
   _m.pushbuf()
   _m.extend( ['<li>'] )
@@ -698,8 +698,8 @@ def body_centerpane() :
   _m.extend( ['the whole, in the building: posterity discovers it in the bricks with which', '\n          '] )
   # lineno:183
   _m.extend( ['they built and which are often used again for better building.', '\n      '] )
-  _m.handletag( _m.popbuftext(), _m.popbuftext(), indent=False, nl='')
-  _m.handletag( _m.popbuftext(), _m.popbuftext(), indent=False, nl='')
+  _m.handletag( _m.popbuftext(), _m.popbuftext(), **{'nl': '', 'oprune': False, 'indent': False, 'iprune': False} )
+  _m.handletag( _m.popbuftext(), _m.popbuftext(), **{'nl': '', 'oprune': False, 'indent': False, 'iprune': False} )
   # lineno:184
   _m.pushbuf()
   _m.extend( ['<li>'] )
@@ -709,7 +709,7 @@ def body_centerpane() :
   _m.extend( ['Be it internet apps, be it desktop apps, build them on pluggdapps, whether your', '\n        '] )
   # lineno:186
   _m.extend( ['applications live or whither, your plugins will go on to build better apps.', '\n      '] )
-  _m.handletag( _m.popbuftext(), _m.popbuftext(), indent=False, nl='')
+  _m.handletag( _m.popbuftext(), _m.popbuftext(), **{'nl': '', 'oprune': False, 'indent': False, 'iprune': False} )
   # lineno:187
   _m.pushbuf()
   _m.extend( ['<li>'] )
@@ -718,9 +718,9 @@ def body_centerpane() :
   _m.extend( ['Start by contributing plugins, grow as you design apps and become a network', '\n        '] )
   # lineno:188
   _m.extend( ['geek.', '\n'] )
-  _m.handletag( _m.popbuftext(), _m.popbuftext(), indent=False, nl='')
-  _m.handletag( _m.popbuftext(), _m.popbuftext(), indent=False, nl='')
-  _m.handletag( _m.popbuftext(), _m.popbuftext(), indent=False, nl='')
+  _m.handletag( _m.popbuftext(), _m.popbuftext(), **{'nl': '', 'oprune': False, 'indent': False, 'iprune': False} )
+  _m.handletag( _m.popbuftext(), _m.popbuftext(), **{'nl': '', 'oprune': False, 'indent': False, 'iprune': False} )
+  _m.handletag( _m.popbuftext(), _m.popbuftext(), **{'nl': '', 'oprune': False, 'indent': False, 'iprune': False} )
   return _m.popbuftext()
 
 # ---- Interface functions
